---
title: <span class="badge object-type-enum"></span> ExtendedStatMetaType
---
# <span class="badge object-type-enum"></span> ExtendedStatMetaType

## Definition

```python
class ExtendedStatMetaType(enum.StrEnum):
    AVG = "avg"
    MIN = "min"
    MAX = "max"
    SUM = "sum"
    COUNT = "count"
    STD_DEVIATION = "std_deviation"
    STD_DEVIATION_BOUNDS_UPPER = "std_deviation_bounds_upper"
    STD_DEVIATION_BOUNDS_LOWER = "std_deviation_bounds_lower"
```
